@@ -1,6 +1,6 @@
 # 2016. 1. 10 by Hans Roh hansroh@gmail.com
 
-__version__ = "0.2.2.2"
+__version__ = "0.2.3.26"
 
 version_info = tuple (map (lambda x: not x.isdigit () and x or int (x),  __version__.split (".")))
 
@@ -20,6 +20,8 @@ from . import deco as versioning
 class udict: pass
 # end of compatibles -----------------------
 
+from .argopt import options, add_option, add_options
+
 # abbreviations ----------------------------------------------------
 def tqdm (iterable, desc = "", color = None, **karg):
     if color:
@@ -51,4 +53,9 @@ def waitf (futures, timeout = None):
     else:
         return concurrent.futures.wait (futures, timeout = timeout)
 
-  
+def wait (futures, timeout = None):
+    dones, undones = waitf (futures)
+    return timeout is None and dones or (dones, undones)
+    
+def as_completed (futures):
+    return concurrent.futures.as_completed (futures)
